﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#include <aws/backup/model/GetRestoreTestingInferredMetadataResult.h>
#include <aws/core/utils/json/JsonSerializer.h>
#include <aws/core/AmazonWebServiceResult.h>
#include <aws/core/utils/StringUtils.h>
#include <aws/core/utils/UnreferencedParam.h>
#include <aws/core/utils/memory/stl/AWSStringStream.h>

#include <utility>

using namespace Aws::Backup::Model;
using namespace Aws::Utils::Json;
using namespace Aws::Utils;
using namespace Aws;

GetRestoreTestingInferredMetadataResult::GetRestoreTestingInferredMetadataResult()
{
}

GetRestoreTestingInferredMetadataResult::GetRestoreTestingInferredMetadataResult(const Aws::AmazonWebServiceResult<JsonValue>& result)
{
  *this = result;
}

GetRestoreTestingInferredMetadataResult& GetRestoreTestingInferredMetadataResult::operator =(const Aws::AmazonWebServiceResult<JsonValue>& result)
{
  JsonView jsonValue = result.GetPayload().View();
  if(jsonValue.ValueExists("InferredMetadata"))
  {
    Aws::Map<Aws::String, JsonView> inferredMetadataJsonMap = jsonValue.GetObject("InferredMetadata").GetAllObjects();
    for(auto& inferredMetadataItem : inferredMetadataJsonMap)
    {
      m_inferredMetadata[inferredMetadataItem.first] = inferredMetadataItem.second.AsString();
    }
  }


  const auto& headers = result.GetHeaderValueCollection();
  const auto& requestIdIter = headers.find("x-amzn-requestid");
  if(requestIdIter != headers.end())
  {
    m_requestId = requestIdIter->second;
  }


  return *this;
}
