﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#include <aws/backupsearch/model/StartSearchJobRequest.h>
#include <aws/core/utils/json/JsonSerializer.h>

#include <utility>

using namespace Aws::BackupSearch::Model;
using namespace Aws::Utils::Json;
using namespace Aws::Utils;

StartSearchJobRequest::StartSearchJobRequest() : 
    m_tagsHasBeenSet(false),
    m_nameHasBeenSet(false),
    m_encryptionKeyArnHasBeenSet(false),
    m_clientTokenHasBeenSet(false),
    m_searchScopeHasBeenSet(false),
    m_itemFiltersHasBeenSet(false)
{
}

Aws::String StartSearchJobRequest::SerializePayload() const
{
  JsonValue payload;

  if(m_tagsHasBeenSet)
  {
   JsonValue tagsJsonMap;
   for(auto& tagsItem : m_tags)
   {
     tagsJsonMap.WithString(tagsItem.first, tagsItem.second);
   }
   payload.WithObject("Tags", std::move(tagsJsonMap));

  }

  if(m_nameHasBeenSet)
  {
   payload.WithString("Name", m_name);

  }

  if(m_encryptionKeyArnHasBeenSet)
  {
   payload.WithString("EncryptionKeyArn", m_encryptionKeyArn);

  }

  if(m_clientTokenHasBeenSet)
  {
   payload.WithString("ClientToken", m_clientToken);

  }

  if(m_searchScopeHasBeenSet)
  {
   payload.WithObject("SearchScope", m_searchScope.Jsonize());

  }

  if(m_itemFiltersHasBeenSet)
  {
   payload.WithObject("ItemFilters", m_itemFilters.Jsonize());

  }

  return payload.View().WriteReadable();
}




