﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#include <aws/bedrock-runtime/model/InvokeModelResult.h>
#include <aws/core/AmazonWebServiceResult.h>
#include <aws/core/utils/StringUtils.h>
#include <aws/core/utils/HashingUtils.h>
#include <aws/core/utils/memory/stl/AWSStringStream.h>

#include <utility>

using namespace Aws::BedrockRuntime::Model;
using namespace Aws::Utils::Stream;
using namespace Aws::Utils;
using namespace Aws;

InvokeModelResult::InvokeModelResult() : 
    m_performanceConfigLatency(PerformanceConfigLatency::NOT_SET)
{
}

InvokeModelResult::InvokeModelResult(InvokeModelResult&& toMove) : 
    m_body(std::move(toMove.m_body)),
    m_contentType(std::move(toMove.m_contentType)),
    m_performanceConfigLatency(toMove.m_performanceConfigLatency),
    m_requestId(std::move(toMove.m_requestId))
{
}

InvokeModelResult& InvokeModelResult::operator=(InvokeModelResult&& toMove)
{
   if(this == &toMove)
   {
      return *this;
   }

   m_body = std::move(toMove.m_body);
   m_contentType = std::move(toMove.m_contentType);
   m_performanceConfigLatency = toMove.m_performanceConfigLatency;
   m_requestId = std::move(toMove.m_requestId);

   return *this;
}

InvokeModelResult::InvokeModelResult(Aws::AmazonWebServiceResult<ResponseStream>&& result)
  : InvokeModelResult()
{
  *this = std::move(result);
}

InvokeModelResult& InvokeModelResult::operator =(Aws::AmazonWebServiceResult<ResponseStream>&& result)
{
  m_body = result.TakeOwnershipOfPayload();

  const auto& headers = result.GetHeaderValueCollection();
  const auto& contentTypeIter = headers.find("content-type");
  if(contentTypeIter != headers.end())
  {
    m_contentType = contentTypeIter->second;
  }

  const auto& performanceConfigLatencyIter = headers.find("x-amzn-bedrock-performanceconfig-latency");
  if(performanceConfigLatencyIter != headers.end())
  {
    m_performanceConfigLatency = PerformanceConfigLatencyMapper::GetPerformanceConfigLatencyForName(performanceConfigLatencyIter->second);
  }

  const auto& requestIdIter = headers.find("x-amzn-requestid");
  if(requestIdIter != headers.end())
  {
    m_requestId = requestIdIter->second;
  }

   return *this;
}
