﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#include <aws/bedrock/model/ListModelCopyJobsResult.h>
#include <aws/core/utils/json/JsonSerializer.h>
#include <aws/core/AmazonWebServiceResult.h>
#include <aws/core/utils/StringUtils.h>
#include <aws/core/utils/UnreferencedParam.h>
#include <aws/core/utils/memory/stl/AWSStringStream.h>

#include <utility>

using namespace Aws::Bedrock::Model;
using namespace Aws::Utils::Json;
using namespace Aws::Utils;
using namespace Aws;

ListModelCopyJobsResult::ListModelCopyJobsResult()
{
}

ListModelCopyJobsResult::ListModelCopyJobsResult(const Aws::AmazonWebServiceResult<JsonValue>& result)
{
  *this = result;
}

ListModelCopyJobsResult& ListModelCopyJobsResult::operator =(const Aws::AmazonWebServiceResult<JsonValue>& result)
{
  JsonView jsonValue = result.GetPayload().View();
  if(jsonValue.ValueExists("nextToken"))
  {
    m_nextToken = jsonValue.GetString("nextToken");

  }

  if(jsonValue.ValueExists("modelCopyJobSummaries"))
  {
    Aws::Utils::Array<JsonView> modelCopyJobSummariesJsonList = jsonValue.GetArray("modelCopyJobSummaries");
    for(unsigned modelCopyJobSummariesIndex = 0; modelCopyJobSummariesIndex < modelCopyJobSummariesJsonList.GetLength(); ++modelCopyJobSummariesIndex)
    {
      m_modelCopyJobSummaries.push_back(modelCopyJobSummariesJsonList[modelCopyJobSummariesIndex].AsObject());
    }
  }


  const auto& headers = result.GetHeaderValueCollection();
  const auto& requestIdIter = headers.find("x-amzn-requestid");
  if(requestIdIter != headers.end())
  {
    m_requestId = requestIdIter->second;
  }


  return *this;
}
