﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#include <aws/cleanroomsml/model/CreateConfiguredModelAlgorithmRequest.h>
#include <aws/core/utils/json/JsonSerializer.h>

#include <utility>

using namespace Aws::CleanRoomsML::Model;
using namespace Aws::Utils::Json;
using namespace Aws::Utils;

CreateConfiguredModelAlgorithmRequest::CreateConfiguredModelAlgorithmRequest() : 
    m_nameHasBeenSet(false),
    m_descriptionHasBeenSet(false),
    m_roleArnHasBeenSet(false),
    m_trainingContainerConfigHasBeenSet(false),
    m_inferenceContainerConfigHasBeenSet(false),
    m_tagsHasBeenSet(false),
    m_kmsKeyArnHasBeenSet(false)
{
}

Aws::String CreateConfiguredModelAlgorithmRequest::SerializePayload() const
{
  JsonValue payload;

  if(m_nameHasBeenSet)
  {
   payload.WithString("name", m_name);

  }

  if(m_descriptionHasBeenSet)
  {
   payload.WithString("description", m_description);

  }

  if(m_roleArnHasBeenSet)
  {
   payload.WithString("roleArn", m_roleArn);

  }

  if(m_trainingContainerConfigHasBeenSet)
  {
   payload.WithObject("trainingContainerConfig", m_trainingContainerConfig.Jsonize());

  }

  if(m_inferenceContainerConfigHasBeenSet)
  {
   payload.WithObject("inferenceContainerConfig", m_inferenceContainerConfig.Jsonize());

  }

  if(m_tagsHasBeenSet)
  {
   JsonValue tagsJsonMap;
   for(auto& tagsItem : m_tags)
   {
     tagsJsonMap.WithString(tagsItem.first, tagsItem.second);
   }
   payload.WithObject("tags", std::move(tagsJsonMap));

  }

  if(m_kmsKeyArnHasBeenSet)
  {
   payload.WithString("kmsKeyArn", m_kmsKeyArn);

  }

  return payload.View().WriteReadable();
}




